buffer_source_bytes

Function buffer_source_bytes 

pub fn buffer_source_bytes(ctx: &Ctx<'_>, value: &Value<'_>) -> Result<Vec<u8>>
A BufferSource: an ArrayBuffer, or a view over one.

Errors

A TypeError when the value is neither, or when the buffer is detached or the view is out of bounds.