util_object

Function util_object 

pub fn util_object<'js>(ctx: &Ctx<'js>) -> Result<Object<'js>>
Every util export on one object, for both the ES module and the require namespace.

Errors

Propagates the property writes and the global reads it makes.