Structs
- Null
- Helper type for converting an None into null instead of undefined. Needed while rquickjs::function::Null has no IntoJs implementation
- Nullable
Opt - Helper type for accepting no value, or null, but considering undefined as a value
- Undefined
- Helper type for treating an undefined value as None, without treating null as None